# Examples

Some examples how to use pydiverse.transform:

* [Quickstart examples](/quickstart)
* [Joining and Tables as Column namespaces](/examples/joining)
* [Aggregation functions](/examples/aggregations)
* [Window functions](/examples/window_functions)
* [Working with real database](/database_testing)
* [Duckdb, Polars, and Parquet](/examples/duckdb_polars_parquet)
* [Best practices / beware the flatfile & embrace working with entities](/examples/best_practices_entities)

```{toctree}
/examples/joining
/examples/aggregations
/examples/window_functions
/database_testing
/examples/duckdb_polars_parquet
```
